@@ -99,7 +99,7 @@ def modify_ws(**kwargs):
     modifier.create_modified_workspace()
     
 kItemChoices = ['workspace', 'dataset', 'category', 'snapshot', 'pdf',
-                'function', 'poi', 'nuisance_parameter', 'global_observables',
+                'function', 'poi', 'nuisance_parameter', 'global_observable',
                 'constrained_nuisance_parameter', 'unconstrained_nuisance_parameter',
                 'auxiliary']
 kDefaultItems = ",".join(['workspace', 'dataset', 'category', 'poi', 'pdf',
@@ -155,4 +155,55 @@ def compare_ws(**kwargs):
     if save_json_data is not None:
         comparer.save_json(save_json_data)
     if save_excel_data is not None:
-        comparer.save_excel(save_excel_data)
\ No newline at end of file
+        comparer.save_excel(save_excel_data)
+        
+        
+@click.command(name='combine_ws')
+@click.option('-i', '--filename', 'source', required=True, 
+              help='Input xml file.')
+@click.option('--save_rename_ws/--skip_rename_ws', default=False, show_default=True,
+              help='Save a temporary workspace after the rename step')
+@click.option('--save_combine_ws/--skip_combine_ws', default=False, show_default=True,
+              help='Save a temporary workspace after the combine step')
+@click.option('-t', '--minimizer_type', default="Minuit2", show_default=True,
+              help='Minimizer type')
+@click.option('-a', '--minimizer_algo', default="Migrad", show_default=True,
+              help='Minimizer algorithm')
+@click.option('-c', '--num_cpu', type=int, default=1, show_default=True,
+              help='Number of CPUs to use per parameter')
+@click.option('-e', '--eps', type=float, default=1.0, show_default=True,
+              help='Convergence criterium')
+@click.option('--retry', type=int, default=0, show_default=True,
+              help='Maximum number of retries upon a failed fit')
+@click.option('--strategy', type=int, default=1, show_default=True,
+              help='Default minimization strategy')
+@click.option('--print_level', type=int, default=-1, show_default=True,
+              help='Minimizer print level')
+@click.option('--fix-cache/--no-fix-cache', default=True, show_default=True,
+              help='Fix StarMomentMorph cache')
+@click.option('--fix-multi/--no-fix-cache',  default=True, show_default=True,
+              help='Fix MultiPdf level 2')
+@click.option('--max_calls', type=int, default=-1, show_default=True,
+              help='Maximum number of function calls')
+@click.option('--max_iters', type=int, default=-1, show_default=True,
+              help='Maximum number of Minuit iterations')
+@click.option('--optimize', type=int, default=2, show_default=True,
+              help='Optimize constant terms')
+@click.option('--offset/--no-offset', default=True, show_default=True,
+              help='Offset likelihood')
+@click.option('-v', '--verbosity',  default="INFO", show_default=True,
+              help='verbosity level ("DEBUG", "INFO", "WARNING", "ERROR")')
+def combine_ws(**kwargs):
+    """
+    Combine workspace from XML config files
+    """
+    _kwargs = {}
+    _aux_kwargs = {}
+    for arg_name in ["source", "verbosity"]:
+        _kwargs[arg_name] = kwargs.pop(arg_name)
+    for arg_name in ["save_rename_ws", "save_combine_ws"]:
+        _aux_kwargs[arg_name] = kwargs.pop(arg_name)
+    _kwargs['minimizer_config'] = kwargs
+    from quickstats.components.workspaces import XMLWSCombiner
+    combiner = XMLWSCombiner(**_kwargs)
+    combiner.run(**_aux_kwargs, save_final_ws=True)    
\ No newline at end of file
