@@ -1,7 +1,7 @@
 from typing import Optional, Union, List
 
 from quickstats.components import AbstractObject, ExtendedModel, ExtendedMinimizer
-from quickstats.components.basics import WSVariables
+from quickstats.components.basics import WSArgument
 from quickstats.utils.common_utils import get_class_that_defined_method
 import ROOT
 
@@ -222,16 +222,16 @@ class AnalysisObject(AbstractObject):
                 self.model.workspace.loadSnapshot(snapshot_name)
                 self.stdout.debug(f"DEBUG: Loaded snapshot \"{snapshot_name}\"")
     
-    def get_variables(self, variable_type:Union[str, WSVariables], sort:bool=True):
+    def get_variables(self, variable_type:Union[str, WSArgument], sort:bool=True):
         return self.model.get_variables(variable_type, sort=sort)
     
     def save_snapshot(self, snapshot_name:Optional[str]=None, 
-                      variables:Optional[Union[ROOT.RooArgSet, str, WSVariables]]=None):
+                      variables:Optional[Union[ROOT.RooArgSet, str, WSArgument]]=None):
         if snapshot_name is not None:
             if variables is None:
                 self.model.workspace.saveSnapshot(snapshot_name, self.model.workspace.allVars())
             else:
-                if isinstance(variables, (str, WSVariables)):
+                if isinstance(variables, (str, WSArgument)):
                     variables = self.get_variables(variables)
                 self.model.workspace.saveSnapshot(snapshot_name, variables)
             self.stdout.debug(f"DEBUG: Saved snapshot \"{snapshot_name}\"")
