@@ -11,7 +11,7 @@ from quickstats.utils.root_utils import load_macro
 from quickstats.utils import common_utils
 from quickstats.utils.io import Verbosity
 from quickstats.maths.numerics import pretty_value
-from quickstats.components.basics import WSVariables
+from quickstats.components.basics import WSArgument
 
 import ROOT
 
@@ -158,16 +158,16 @@ class AsymptoticCLs(AnalysisObject):
         self.load_snapshot(name) 
     
     def load_conditional_snapshot(self, mu:float, 
-                                  target:Union[str, WSVariables]=WSVariables.NUISANCE_PARAMETERS):
+                                  target:Union[str, WSArgument]=WSArgument.NUISANCE_PARAMETER):
         name = self.get_conditional_snapsot_name(mu, target)
         self.load_snapshot(name)
     
     def get_conditional_snapsot_name(self, mu:float, 
-                                     target:Union[str, WSVariables]=WSVariables.NUISANCE_PARAMETERS):
-        target = WSVariables.parse(target)
-        if target == WSVariables.NUISANCE_PARAMETERS:
+                                     target:Union[str, WSArgument]=WSArgument.NUISANCE_PARAMETER):
+        target = WSArgument.parse(target)
+        if target == WSArgument.NUISANCE_PARAMETER:
             name = self.model._DEFAULT_NAMES_['conditional_nuis'].format(mu=pretty_value(mu))
-        elif target == WSVariables.GLOBAL_OBSERVABLES:
+        elif target == WSArgument.GLOBAL_OBSERVABLE:
             name = self.model._DEFAULT_NAMES_['conditional_globs'].format(mu=pretty_value(mu))
         else:
             raise ValueError(f'unknown conditional snapshot target "{target}"')
@@ -406,7 +406,7 @@ class AsymptoticCLs(AnalysisObject):
         
     def fill_mappings(self, nll:"ROOT.RooNLLVar", dataset:"ROOT.RooDataSet",
                       mu_hat:float, nll_mu_hat:float):
-        snapshot_name = self.get_conditional_snapsot_name(mu_hat, target=WSVariables.GLOBAL_OBSERVABLES)
+        snapshot_name = self.get_conditional_snapsot_name(mu_hat, target=WSArgument.GLOBAL_OBSERVABLE)
         self.nll_maps[nll] = {}
         self.nll_maps[nll]['dataset'] = dataset
         self.nll_maps[nll]['snapshot'] = snapshot_name
@@ -479,8 +479,8 @@ class AsymptoticCLs(AnalysisObject):
                                                    minimizer_options=self.default_minimizer_options,
                                                    nll_options=self.default_nll_options)
         asimov_n_nll = self.create_nll(asimov_data_n)
-        self.load_conditional_snapshot(n_times_sigma, target=WSVariables.GLOBAL_OBSERVABLES)
-        self.load_conditional_snapshot(n_times_sigma, target=WSVariables.NUISANCE_PARAMETERS)
+        self.load_conditional_snapshot(n_times_sigma, target=WSArgument.GLOBAL_OBSERVABLE)
+        self.load_conditional_snapshot(n_times_sigma, target=WSArgument.NUISANCE_PARAMETER)
         self.set_poi_value(n_times_sigma)
         nll_value = asimov_n_nll.getVal()
         self.save_nll_snapshot(asimov_n_nll, n_times_sigma)
@@ -503,8 +503,8 @@ class AsymptoticCLs(AnalysisObject):
         obs_nll = self.create_nll(self.data)
         self.nll_maps[obs_nll] = {"dataset": self.data, "snapshot": self.nom_glob_name}
         self.dataset_maps[self.data] = obs_nll
-        self.save_snapshot(self.nom_glob_name, variables=WSVariables.GLOBAL_OBSERVABLES)
-        self.save_snapshot(self.nom_nuis_name, variables=WSVariables.NUISANCE_PARAMETERS)
+        self.save_snapshot(self.nom_glob_name, variables=WSArgument.GLOBAL_OBSERVABLE)
+        self.save_snapshot(self.nom_nuis_name, variables=WSArgument.NUISANCE_PARAMETER)
         
         if self.asimov_data_0 is None:
             # generate asimov dataset on the fly
@@ -524,8 +524,8 @@ class AsymptoticCLs(AnalysisObject):
         self.summary[0] = {'dataset': asimov_data_0, 'nll': asimov_0_nll}
         self.set_poi_value(0)
         self.save_nll_snapshot(asimov_0_nll, 0)
-        self.load_conditional_snapshot(0, target=WSVariables.GLOBAL_OBSERVABLES)
-        self.load_conditional_snapshot(0, target=WSVariables.NUISANCE_PARAMETERS)
+        self.load_conditional_snapshot(0, target=WSArgument.GLOBAL_OBSERVABLE)
+        self.load_conditional_snapshot(0, target=WSArgument.NUISANCE_PARAMETER)
         nll_value = asimov_0_nll.getVal()
         self.fill_mappings(asimov_0_nll, asimov_data_0, 0, nll_value)
         
@@ -553,7 +553,7 @@ class AsymptoticCLs(AnalysisObject):
             limits[n] = self.evaluate_limit_band(n, med_limit)
         
         # compute observed limit
-        self.load_conditional_snapshot(0, target=WSVariables.NUISANCE_PARAMETERS)
+        self.load_conditional_snapshot(0, target=WSArgument.NUISANCE_PARAMETER)
         # relax the range for observed limit
         if not self.adjust_fit_range:
             self.poi.setRange(poi_range_tmp[0], poi_range_tmp[1])
