@@ -13,6 +13,8 @@ from typing import List, Optional, Union, Dict, Set, Tuple
 import numpy as np
 
 import ROOT
+from ROOT.RooPrintable import (kName, kClassName, kValue, kArgs, kExtras, kAddress,
+                               kTitle, kCollectionHeader, kSingleLine)
 
 import quickstats
 from quickstats import semistaticmethod
@@ -24,7 +26,8 @@ from quickstats.utils.roofit_utils import (get_variable_attributes, variable_col
                                            get_relevant_components)
 from quickstats.interface.root import TH1, RooDataSet, RooArgSet, RooMsgService
 from quickstats.interface.root import roofit_extension as rf_ext
-from quickstats.components.basics import WSVariables, SetValueMode
+from quickstats.interface.root.roofit_extension import get_str_data
+from quickstats.components.basics import WSArgument, SetValueMode
 
 class ExtendedModel(AbstractObject):
     
@@ -47,6 +50,11 @@ class ExtendedModel(AbstractObject):
         'range_sideband_high': 'SBHi'
     }
     
+    _DEFAULT_CONTENT_ = {
+        WSArgument.PDF: kClassName|kName|kArgs,
+        WSArgument.FUNCTION: kClassName|kName|kArgs
+    }
+    
     def __init__(self, fname:str, ws_name:Optional[str]=None, mc_name:Optional[str]=None,
                  data_name:Optional[str]="combData", snapshot_name:Optional[Union[List[str], str]]=None,
                  binned_likelihood:bool=True, tag_as_measurement:Optional[str]=None,
@@ -1427,44 +1435,43 @@ class ExtendedModel(AbstractObject):
             pdf.close()
         return None
     
-    def get_variables(self, variable_type:Union[str, WSVariables], sort:bool=True):
-        _variable_type = WSVariables.parse(variable_type)
-        if _variable_type == WSVariables.VARIABLES:
+    def get_variables(self, variable_type:Union[str, WSArgument], sort:bool=True):
+        resolved_vtype = WSArgument.parse(variable_type)
+        if not resolved_vtype.is_variable:
+            raise ValueError(f"the collection \"{variable_type}\" does not contain members of the type \"RooRealVar\"")
+        if resolved_vtype == WSArgument.VARIABLE:
             variables = self.workspace.allVars()
-        elif _variable_type == WSVariables.OBSERVABLES:
-            variables = self.observables
-        elif _variable_type == WSVariables.POIS:
+        elif resolved_vtype == WSArgument.OBSERVABLE:
+            if isinstance(self.pdf, ROOT.RooSimultaneous):
+                variables = self.observables.Clone()
+                cat = self.pdf.indexCat()
+                variables.remove(cat)
+            else:
+                variables = self.observables
+        elif resolved_vtype == WSArgument.POI:
             variables = self.pois
-        elif _variable_type == WSVariables.GLOBAL_OBSERVABLES:
+        elif resolved_vtype == WSArgument.GLOBAL_OBSERVABLE:
             variables = self.global_observables
-        elif _variable_type == WSVariables.NUISANCE_PARAMETERS:
+        elif resolved_vtype == WSArgument.NUISANCE_PARAMETER:
             variables = self.nuisance_parameters
-        elif _variable_type == WSVariables.CONSTRAINED_NUISANCE_PARAMETERS:
+        elif resolved_vtype == WSArgument.CONSTRAINED_NUISANCE_PARAMETER:
             variables = RooArgSet.from_list(self.get_constrained_nuisance_parameters())
-        elif _variable_type == WSVariables.UNCONSTRAINED_NUISANCE_PARAMETERS:
+        elif resolved_vtype == WSArgument.UNCONSTRAINED_NUISANCE_PARAMETER:
             variables = RooArgSet.from_list(self.get_unconstrained_nuisance_parameters())
-        elif _variable_type == WSVariables.CONSTRAINTS:
+        elif resolved_vtype == WSArgument.CONSTRAINT:
             nuis_list, glob_list, pdf_list = self.pair_constraints(sort=sort)
             return RooArgSet.from_list(nuis_list), RooArgSet.from_list(glob_list), RooArgSet.from_list(pdf_list)
-        elif _variable_type == WSVariables.AUXILIARY:
-            variables           = self.get_variables("variables")
-            pois                = self.get_variables("pois")
-            nuisance_parameters = self.get_variables("nuisance_parameters")
-            global_observables  = self.get_variables("global_observables")
-            observables         = self.get_variables("observables")
+        elif resolved_vtype == WSArgument.AUXILIARY:
+            variables           = self.get_variables(WSArgument.VARIABLE)
+            pois                = self.get_variables(WSArgument.POI)
+            nuisance_parameters = self.get_variables(WSArgument.NUISANCE_PARAMETER)
+            global_observables  = self.get_variables(WSArgument.GLOBAL_OBSERVABLE)
+            observables         = self.get_variables(WSArgument.OBSERVABLE)
             variables.remove(pois)
             variables.remove(nuisance_parameters)
             variables.remove(global_observables)
             variables.remove(observables)
-        elif _variable_type == WSVariables.NON_CONSTRAINT_VARIABLES:
-            variables           = self.get_variables("variables")
-            nuisance_parameters = self.get_variables("nuisance_parameters")
-            global_observables  = self.get_variables("global_observables")
-            observables         = self.get_variables("observables")
-            variables.remove(nuisance_parameters)
-            variables.remove(global_observables)
-            variables.remove(observables)
-        elif _variable_type == WSVariables.CORE:
+        elif resolved_vtype == WSArgument.CORE:
             variables = ROOT.RooArgSet()
             variables.add(self.nuisance_parameters)
             variables.add(self.global_observables)
@@ -1475,24 +1482,46 @@ class ExtendedModel(AbstractObject):
             return RooArgSet.sort(variables)
         return variables
     
-    def as_dataframe(self, variable_type:Union[str, WSVariables, ROOT.RooArgSet],
-                     asym_error:bool=False):
-        if isinstance(variable_type, ROOT.RooArgSet):
-            vcollection = variable_type
+    def as_dataframe(self, attribute:Union[str, WSArgument, ROOT.RooArgSet],
+                     asym_error:bool=False, content:Optional[int]=None):
+        """
+        View workspace attribute in the form of a dataframe
+        """
+        if isinstance(attribute, ROOT.RooArgSet):
+            collection = attribute
         else:
-            _variable_type = WSVariables.parse(variable_type)
+            resolved_attribute = WSArgument.parse(attribute)
+            if resolved_attribute.is_variable:
+                collection = self.get_variables(resolved_attribute)
             # for the special case of displaying constrain terms
             # will print the tuple of names of NP, Global Observables and Constrain Pdf
-            if _variable_type == WSVariables.CONSTRAINTS:
+            elif resolved_attribute == WSArgument.CONSTRAINT:
                 data = self.pair_constraints(to_str=True, fmt="dict")
                 import pandas as pd
                 df = pd.DataFrame(data).rename(columns={'pdf': 'constraint pdf',
                                                         'nuis': 'nuisance parameters',
                                                         'globs': 'global observables'})
                 return df
+            elif resolved_attribute in [WSArgument.PDF, WSArgument.FUNCTION]:
+                if resolved_attribute == WSArgument.PDF:
+                    if content is None:
+                        content = self._DEFAULT_CONTENT_[WSArgument.PDF]
+                    collection = self.workspace.allPdfs()
+                elif resolved_attribute == WSArgument.FUNCTION:
+                    if content is None:
+                        content = self._DEFAULT_CONTENT_[WSArgument.FUNCTION]
+                    collection = self.workspace.allFunctions()
+                else:
+                    raise RuntimeError("unexpected error")
+                df_1 = get_str_data(collection, fill_classes=True,
+                                    fill_definitions=True, content=content,
+                                    style=kSingleLine, fmt="dataframe")
+                df_2 = variable_collection_to_dataframe(collection)
+                df = df_1.merge(df_2, on="name", how='outer', sort=True, validate="one_to_one")
+                return df
             else:
-                vcollection = self.get_variables(_variable_type)
-        df = variable_collection_to_dataframe(vcollection, asym_error=asym_error)
+                raise ValueError(f"unsupported workspace attribute: {attribute}")
+        df = variable_collection_to_dataframe(collection, asym_error=asym_error)
         return df
     
     def rename_dataset(self, rename_map:Dict):
@@ -1531,7 +1560,7 @@ class ExtendedModel(AbstractObject):
         if 'dataset' in items:
             datasets = self.workspace.allData()
             summary_str += f"Datasets ({len(datasets)}):\n"
-            summary_str += "".join([f"\t{obs.GetName()}\n" for obs in datasets])
+            summary_str += "".join([f"\t{ds.GetName()}\n" for ds in datasets])
         # snapshots
         if ('snapshot' in items):
             if (quickstats.root_version >= (6, 26, 0)):
