@@ -16,7 +16,7 @@ from quickstats.components import AbstractObject, ExtendedModel
 from quickstats.utils.io import Verbosity, get_colored_text, format_comparison_text
 from quickstats.utils.root_utils import load_macro, get_macro_dir
 from quickstats.maths.numerics import is_float, pretty_value
-from quickstats.components.basics import WSVariables
+from quickstats.components.basics import WSArgument
 from quickstats.utils.enums import GeneralEnum
 from quickstats.interface.root.roofit_extension import get_str_data
 
@@ -46,21 +46,19 @@ class WSItem(GeneralEnum):
     DATASET                          = (3,  WSItemType.OTHER, 'Datasets', None, False, False, 0b11011)
     PDF                              = (4,  WSItemType.PDF, 'Pdfs', None, True, True, 0b01011)
     FUNCTION                         = (5,  WSItemType.FUNCTION, 'Functions', None, True, True, 0b01011)
-    POI                              = (6,  WSItemType.VARIABLE, 'POIs', WSVariables.POIS, True, False, 0b01011)
+    POI                              = (6,  WSItemType.VARIABLE, 'POIs', WSArgument.POI, True, False, 0b01011)
     NUISANCE_PARAMETER               = (7,  WSItemType.VARIABLE, 'Nuisance Parameters',
-                                        WSVariables.NUISANCE_PARAMETERS, True, False, 0b01011)
+                                        WSArgument.NUISANCE_PARAMETER, True, False, 0b01011)
     GLOBAL_OBSERVABLE                = (8,  WSItemType.VARIABLE, 'Global Observables',
-                                        WSVariables.GLOBAL_OBSERVABLES, True, False, 0b01011)    
+                                        WSArgument.GLOBAL_OBSERVABLE, True, False, 0b01011)    
     CONSTRAINED_NUISANCE_PARAMETER   = (9,  WSItemType.VARIABLE, 'Constrained Nuisance Parameters',
-                                        WSVariables.CONSTRAINED_NUISANCE_PARAMETERS, True, False, 0b01011)
+                                        WSArgument.CONSTRAINED_NUISANCE_PARAMETER, True, False, 0b01011)
     UNCONSTRAINED_NUISANCE_PARAMETER = (10, WSItemType.VARIABLE, 'Unconstrained Nuisance Parameters',
-                                        WSVariables.UNCONSTRAINED_NUISANCE_PARAMETERS, True, False, 0b01011)
+                                        WSArgument.UNCONSTRAINED_NUISANCE_PARAMETER, True, False, 0b01011)
     AUXILIARY                        = (11, WSItemType.VARIABLE, 'Auxiliary Variables',
-                                        WSVariables.AUXILIARY, True, False, 0b01011)
-    NON_CONSTRAINT_VARIABLE          = (12, WSItemType.VARIABLE, 'Non-constraint Variables',
-                                        WSVariables.NON_CONSTRAINT_VARIABLES, True, False, 0b01011)
+                                        WSArgument.AUXILIARY, True, False, 0b01011)
     
-    def __init__(self, enum_id:int, item_type:WSItemType, title:str, var_repr:Optional[WSVariables],
+    def __init__(self, enum_id:int, item_type:WSItemType, title:str, var_repr:Optional[WSArgument],
                  support_definition:bool, is_composite:bool, default_visibility:int):
         self.enum_id   = enum_id
         self.item_type = item_type
@@ -382,19 +380,38 @@ class ComparisonData:
         if ext_ref is None:
             ext_ref = {}
         df_1 = df[df["_merge"] == "left_only"]
-        df_2 = df[df["_merge"] == "right_only"].set_index("name")
-        alt_names = df_1["name_alt"].values
-        contents_1 = list(df_1["definition_left"].values)
+        df_2 = df[df["_merge"] == "right_only"]
+        orig_names_1 = df_1['name'].values
+        orig_names_2 = df_2['name'].values
+        alt_names_1 = df_1["name_alt"].values
+        alt_names_2 = df_2["name_alt"].values
+        mapping_1 = dict(zip(orig_names_1, alt_names_1))
+        mapping_2 = dict(zip(orig_names_2, alt_names_2))
+        df_1.set_index('name', inplace=True)
+        df_2.set_index('name', inplace=True)
+        contents_1 = []
         contents_2 = []
-        for alt_name in alt_names:
-            if alt_name in df_2.index:
-                definition = df_2.loc[alt_name]["definition_right"]
-                contents_2.append(definition)
+        for name, alt_name in mapping_1.items():
+            contents_1.append(df_1.loc[name]["definition_left"])
+            # left same item type -> right same item type
+            if (alt_name in mapping_2):
+                if (mapping_2[alt_name] == name):
+                    contents_2.append(df_2.loc[alt_name]["definition_right"])
+            # left same item type -> right diff item type
+            elif (alt_name  in ext_ref):
+                contents_2.append(ext_ref[alt_name])
             else:
-                if alt_name in ext_ref:
-                    contents_2.append(ext_ref[alt_name])
-                else:
-                    contents_2.append(f"{alt_name} [definition not inferred]")
+                contents_2.append(f"{alt_name} [definition not inferred]")
+        for name, alt_name in mapping_2.items():
+            # left same item type -> right same item type; already dealt with
+            if (alt_name in mapping_1):
+                continue
+            contents_2.append(df_2.loc[name]["definition_right"])
+            # left diff item type -> right same item type
+            if (alt_name  in ext_ref):
+                contents_1.append(ext_ref[alt_name])
+            else:
+                contents_1.append(f"{alt_name} [definition not inferred]")            
         return contents_1, contents_2
     
     def get_summary_str(self, visibility:int=0b00011, indent:str="   ",
