@@ -19,7 +19,7 @@ from quickstats.utils.io import Verbosity
 from quickstats.utils.root_utils import load_macro, get_macro_dir
 from quickstats.utils.common_utils import format_delimiter_enclosed_text
 from quickstats.maths.numerics import is_float, pretty_value
-from quickstats.components.basics import WSVariables
+from quickstats.components.basics import WSArgument
 from quickstats.components.workspaces import XMLWSBase, WSObjectType, AsimovHandler
 
 from quickstats.utils.enums import GeneralEnum
@@ -377,7 +377,7 @@ class XMLWSModifier(XMLWSBase):
         
     def copy_snapshot_variables(self, old_ws:ROOT.RooWorkspace, old_mc:ROOT.RooStats.ModelConfig,
                                 new_ws:ROOT.RooWorkspace, new_mc:ROOT.RooStats.ModelConfig,
-                                snapshot_name:str, variable_type:Union[WSVariables, str],
+                                snapshot_name:str, variable_type:Union[WSArgument, str],
                                 rename_map:Optional[Dict]=None):
         snapshot = old_ws.loadSnapshot(snapshot_name)
         if not snapshot:
@@ -409,15 +409,15 @@ class XMLWSModifier(XMLWSBase):
         variables.add(renamed_variables_new)
         new_mc.saveSnapshot(snapshot_name, variables)
         
-    def get_variables(self, mc:ROOT.RooStats.ModelConfig, variable_type:Union[WSVariables, str]):
-        _variable_type = WSVariables.parse(variable_type)
-        if _variable_type == WSVariables.NUISANCE_PARAMETERS:
+    def get_variables(self, mc:ROOT.RooStats.ModelConfig, variable_type:Union[WSArgument, str]):
+        _variable_type = WSArgument.parse(variable_type)
+        if _variable_type == WSArgument.NUISANCE_PARAMETER:
             variables = mc.GetNuisanceParameters()
-        elif _variable_type == WSVariables.GLOBAL_OBSERVABLES:
+        elif _variable_type == WSArgument.GLOBAL_OBSERVABLE:
             variables = mc.GetGlobalObservables()
-        elif _variable_type == WSVariables.POIS:
+        elif _variable_type == WSArgument.POI:
             variables = mc.GetParametersOfInterest()
-        elif _variable_type == WSVariables.CORE:
+        elif _variable_type == WSArgument.CORE:
             variables = ROOT.RooArgSet()
             variables.add(mc.GetNuisanceParameters())
             variables.add(mc.GetGlobalObservables())
@@ -433,22 +433,22 @@ class XMLWSModifier(XMLWSBase):
         nuis_snapshot_names = self.config['snapshot_nuis']
         for nuis_snapshot_name in nuis_snapshot_names:
             self.copy_snapshot_variables(old_ws, old_mc, new_ws, new_mc, nuis_snapshot_name,
-                                         WSVariables.NUISANCE_PARAMETERS, rename_map)
+                                         WSArgument.NUISANCE_PARAMETER, rename_map)
         # global observable snapshots                  
         globs_snapshot_names = self.config['snapshot_globs']
         for globs_snapshot_name in globs_snapshot_names:
             self.copy_snapshot_variables(old_ws, old_mc, new_ws, new_mc, globs_snapshot_name,
-                                         WSVariables.GLOBAL_OBSERVABLES, rename_map)
+                                         WSArgument.GLOBAL_OBSERVABLE, rename_map)
         # poi snapshots 
         pois_snapshot_names = self.config['snapshot_pois']
         for pois_snapshot_name in pois_snapshot_names:
             self.copy_snapshot_variables(old_ws, old_mc, new_ws, new_mc, pois_snapshot_name,
-                                         WSVariables.POIS, rename_map)
+                                         WSArgument.POI, rename_map)
         # nuisance parameter + global observable + poi snapshots 
         vars_snapshot_names = self.config['snapshot_all']
         for vars_snapshot_name in vars_snapshot_names:
             self.copy_snapshot_variables(old_ws, old_mc, new_ws, new_mc, vars_snapshot_name,
-                                         WSVariables.CORE, rename_map)
+                                         WSArgument.CORE, rename_map)
         
     def create_model_config(self, old_mc:ROOT.RooStats.ModelConfig, new_ws:ROOT.RooWorkspace,
                             rename_map:Optional[Dict]=None):
