@@ -11,7 +11,7 @@ from quickstats import semistaticmethod
 from quickstats.parsers import ParamParser
 from quickstats.concurrent import ParameterisedRunner
 from quickstats.components import AsymptoticCLs
-from quickstats.utils.common_utils import batch_makedirs
+from quickstats.utils.common_utils import batch_makedirs, json_load
 
 class ParameterisedAsymptoticCLs(ParameterisedRunner):
     def __init__(self, input_path:str, config:Optional[Dict]=None,
@@ -51,7 +51,7 @@ class ParameterisedAsymptoticCLs(ParameterisedRunner):
     @semistaticmethod
     def _cached_return(self, outname:str):
         with open(outname, 'r') as f:
-            limits = json.load(f)
+            limits = json_load(f)
             return limits
     
     @semistaticmethod
@@ -136,5 +136,6 @@ class ParameterisedAsymptoticCLs(ParameterisedRunner):
         
         if outname is not None:
             outpath = os.path.join(outdir, outname)
-            with open(outpath, "w") as f:
-                json.dump(final_result, f, indent=2)
\ No newline at end of file
+            with open(outpath, "w") as file:
+                json.dump(final_result, file, indent=2)
+                file.truncate()
\ No newline at end of file
