@@ -197,7 +197,12 @@ class ParamParser:
                                    f"in the parameter expression: {param_str}")
             param_values[param_name] = np.concatenate([param_values[param_name], values])
         param_names = list(param_values.keys())
-        combinations = [param_values[param_name] for param_name in param_names]
+        # convert to numpy arrays
+        combinations = [np.array(param_values[param_name]) for param_name in param_names]
+        # take care of rounding errors and negative zeros
+        combinations = [(arr.round(decimals=8) + 0.0) for arr in combinations]
+        # take care of duplicate ploints
+        combinations = [np.unique(arr) for arr in combinations]
         combinations = itertools.product(*combinations)
         param_points = []
         for combination in combinations:
