@@ -154,6 +154,7 @@ class UpperLimit2DPlot(AbstractPlot):
                          observed_marker:Optional[str]='o', 
                          sigma_band_hatch:Optional[str]=None,
                          alpha:float=1.,
+                         linewidth:float=1.,
                          sec:bool=False):
         
         if color_pallete is None:
@@ -196,19 +197,19 @@ class UpperLimit2DPlot(AbstractPlot):
             handle_observed = draw_fn(indices, obs_limits, color=color_pallete['observed'], 
                                       label=labels['observed'], 
                                       marker=observed_marker,
-                                      alpha=alpha)
+                                      alpha=alpha, linewidth=linewidth)
             handles_map['observed'] = handle_observed[0]
             
         handle_expected = draw_fn(indices, exp_limits, color=color_pallete['expected'],
                                   linestyle='--',
                                   label=labels['expected'],
-                                  alpha=alpha)
+                                  alpha=alpha, linewidth=linewidth)
         handles_map['expected'] = handle_expected[0]
 
         self.update_legend_handles(handles_map, sec=sec)
             
     def draw(self, xlabel:str="", ylabel:str="", ylim=None, xlim=None,
-             log:bool=False, draw_observed:bool=True, observed_marker:Optional[str]='o'):
+             log:bool=False, draw_observed:bool=True, observed_marker:Optional[str]='o', linewidth:float=1):
         
         ax = self.draw_frame()
         
@@ -236,7 +237,8 @@ class UpperLimit2DPlot(AbstractPlot):
                               labels=self.labels,
                               observed_marker=observed_marker, 
                               sigma_band_hatch=sigma_band_hatch,
-                              alpha=alpha)
+                              alpha=alpha,
+                              linewidth=linewidth)
         if self.curve_data is not None:
             self.draw_curve(ax, self.curve_data)   
         if self.highlight_data is not None:
@@ -268,4 +270,4 @@ class UpperLimit2DPlot(AbstractPlot):
             handles = handles + handles_sec
             labels  = labels + labels_sec
         ax.legend(handles, labels, **self.styles['legend'])
-        return ax
\ No newline at end of file
+        return ax
