@@ -1,17 +1,12 @@
 from typing import Optional, Union, Dict, List
 
+import numpy as np
 import matplotlib.patches as patches
-import matplotlib.lines as lines
-import pandas as pd
 
 from quickstats.plots import AbstractPlot
 from quickstats.plots.template import create_transform
 from quickstats.utils.common_utils import combine_dict
 
-from scipy import interpolate
-import numpy as np
-
-
 class UpperLimit3DPlot(AbstractPlot):
     
     STYLES = {
@@ -125,23 +120,47 @@ class UpperLimit3DPlot(AbstractPlot):
         X_grid, Y_grid = np.meshgrid(X_points, Y_points)
         return X_grid, Y_grid
 
-    def replot_bands(self, ax, cp, labels):
+    def return_points(self, paths):
+        out, inn = 0, 1
+        segment1_start = paths[0].vertices[0]
+        segment1_end = paths[0].vertices[-1]
+        if len(paths) == 2 and (segment1_start != segment1_end).all():
+            segment2_start = paths[1].vertices[0]
+            segment2_end = paths[1].vertices[-1]
+            if np.square(segment2_start-segment2_end) > np.square(segment1_start-segment1_end):
+                out, inn = 1, 0
+            return (paths[out].vertices, paths[inn].vertices)
+        else:
+            return (np.concatenate([i.vertices for i in paths]),)
+
+    def plot_bands(self, ax, cp, labels, cp_obs=None):
         # loop over contour curves
         # assumption: 0,4 = 2sigma outer/inner boundaries; 1,3 = 1sigma outer/inner boundaries; 2 = expectation
-        inner2 = cp.collections[0].get_paths()[0].vertices
-        inner1 = cp.collections[1].get_paths()[0].vertices
-        center = cp.collections[2].get_paths()[0].vertices
-        outer1 = cp.collections[3].get_paths()[0].vertices
-        outer2 = cp.collections[4].get_paths()[0].vertices
+        inner2 = self.return_points(cp.collections[0].get_paths())
+        inner1 = self.return_points(cp.collections[1].get_paths())
+        center = self.return_points(cp.collections[2].get_paths())
+        outer1 = self.return_points(cp.collections[3].get_paths())
+        outer2 = self.return_points(cp.collections[4].get_paths())
+        if cp_obs:
+            observ = self.return_points(cp_obs.collections[0].get_paths())
 
         # fill color from outside to inside
-        handle_2sigma = ax.fill(outer2[:,0], outer2[:,1], self.color_pallete['2sigma'], label=labels['2sigma'], zorder=1)
-        handle_1sigma = ax.fill(outer1[:,0], outer1[:,1], self.color_pallete['1sigma'], label=labels['1sigma'], zorder=1)
-        handle_expected = ax.plot(center[:,0], center[:,1], self.color_pallete['expected'], label=labels['expected'], zorder=1)
-        ax.fill(inner1[:,0], inner1[:,1], self.color_pallete['2sigma'], zorder=1)
-        ax.fill(inner2[:,0], inner2[:,1], self.color_pallete['excluded'], zorder=1)
+        handle_2sigma = ax.fill(outer2[0][:,0], outer2[0][:,1], self.color_pallete['2sigma'], label=labels['2sigma'], zorder=1)
+        handle_1sigma = ax.fill(outer1[0][:,0], outer1[0][:,1], self.color_pallete['1sigma'], label=labels['1sigma'], zorder=1)
+        handle_expected = ax.plot(center[0][:,0], center[0][:,1], self.color_pallete['expected'], ls='--', label=labels['expected'], zorder=2)
+        ax.fill(inner1[0][:,0], inner1[0][:,1], self.color_pallete['2sigma'], zorder=1)
+        ax.fill(inner2[0][:,0], inner2[0][:,1], self.color_pallete['excluded'], zorder=1)
+        if len(outer2) > 1:
+            handle_2sigma = ax.fill(outer2[1][:,0], outer2[1][:,1], self.color_pallete['excluded'], zorder=1)
+        if len(outer1) + len(center) + len(inner1) + len(inner2) > 4 :
+            print('WARN', len(outer1) , len(center) , len(inner1) , len(inner2))
+
+        if cp_obs:
+            handle_observed = ax.plot(observ[0][:,0], observ[0][:,1], self.color_pallete['observed'], ls='-', label=labels['observed'], zorder=2)
 
         self.update_legend_handles({'2sigma': handle_2sigma[0], '1sigma': handle_1sigma[0], 'expected': handle_expected[0]})
+        if cp_obs:
+            self.update_legend_handles({'observed': handle_observed[0]})
 
     def draw_single_data(self, ax, df, x='klambda', y='k2v', scale_factor=None,
                          theory_grid=None,
@@ -172,12 +191,14 @@ class UpperLimit3DPlot(AbstractPlot):
         expectation_point_list['-1sigma'] = df['-1'] * scale_factor
         expectation_point_list['2sigma'] = df['2'] * scale_factor
         expectation_point_list['-2sigma'] = df['-2'] * scale_factor
-        expectation_point_list['obs'] = df['obs'] * scale_factor
+        if draw_observed:
+            expectation_point_list['obs'] = df['obs'] * scale_factor
         
         exp_grids = {}
         for i in expectation_point_list.keys():
             if i == 'points':
                 continue
+            from scipy import interpolate
             exp_grids[i] = interpolate.griddata(expectation_point_list['points'], 
                                                 expectation_point_list[i], np.stack((X_grid, Y_grid), axis=2))
         
@@ -193,7 +214,18 @@ class UpperLimit3DPlot(AbstractPlot):
         Z_grid[theory_grid - exp_grids['-2sigma'] < 0] = -2.5
 
         cp = ax.contour(X_grid, Y_grid, Z_grid, levels=[-2, -1, 0, 1, 2], linewidths=2, alpha=0, zorder=0)
-        self.replot_bands(ax, cp, labels)
+        #ax.contourf(X_grid, Y_grid, Z_grid, levels=[-2, -1, 0, 1, 2], linewidths=2, alpha=1, zorder=0, cmap='GnBu')
+
+        if draw_observed:
+            Z_grid_obs = np.zeros(theory_grid.shape)
+            Z_grid_obs[theory_grid - exp_grids['obs'] >= 0] = 0.5
+            Z_grid_obs[theory_grid - exp_grids['obs'] < 0] = -0.5
+
+            cp_obs = ax.contour(X_grid, Y_grid, Z_grid_obs, levels=[0], linewidths=2, alpha=0, zorder=0)
+
+        # Plot 1 and 2 sigma bands
+        self.plot_bands(ax, cp, labels, cp_obs if draw_observed else None)
+
 
     def draw(self, x:str="", y:str="", xlabel:str="", ylabel:str="", scale_factor=None, theory_grid=None, ylim=None, xlim=None,
              draw_observed:bool=True, observed_marker:Optional[str]='o', draw_sm_line:bool=False):
