@@ -125,14 +125,36 @@ def get_data_size(data):
         return len(data)
     else:
         return 1
+    
+def root_to_dict(filename:str, simplify:bool=True):
+    f = ROOT.TFile(filename)
+    if is_corrupt(f):
+        raise RuntimeError(f"corrupted ROOT file: {filename}")
+    treenames = [t.GetName() for t in f.GetListOfKeys()]
+    result = {}
+    for treename in treenames:
+        tree = f.Get(treename)
+        rdf = ROOT.RDataFrame(tree)
+        data = rdf.AsNumpy()
+        for branch in data:
+            # convert std::string to python string
+            if rdf.GetColumnType(branch) == "string":
+                data[branch] = np.char.mod('%s', data[branch])
+            # unwrap array if size is 1
+            if simplify and (data[branch].shape[0] == 1):
+                data[branch] = data[branch][0]
+        result[treename] = data
+    return result    
 
 def uproot_to_dict(file):
     result = {}
     for tree in file.values():
-        tree_name = tree.name.decode('utf-8')
+        #tree_name = tree.name.decode('utf-8')
+        tree_name = tree.name
         result[tree_name] = {}
         for branch in tree.values():
-            branch_name = branch.name.decode('utf-8')
+            #branch_name = branch.name.decode('utf-8')
+            branch_name = branch.name
             arr = process_uproot_array(branch.array())
             value = arr[0] if len(arr) == 1 else arr
             result[tree_name][branch_name] = value    
